"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.register = void 0;
const vscode = require("vscode-languageserver");
const transforms_1 = require("../utils/transforms");
const completion_1 = require("./completion");
const previewer = require("../utils/previewer");
const shared = require("@volar/shared");
function register(languageService, getTextDocument, host) {
    return async (item, newOffset) => {
        var _a, _b, _c, _d;
        const data = item.data;
        const fileName = data.fileName;
        const offset = newOffset !== null && newOffset !== void 0 ? newOffset : data.offset;
        const name = data.name;
        const source = data.source;
        const document = getTextDocument(data.uri);
        const [formatOptions, preferences] = document ? await Promise.all([
            (_b = (_a = host.getFormatOptions) === null || _a === void 0 ? void 0 : _a.call(host, document)) !== null && _b !== void 0 ? _b : {},
            (_d = (_c = host.getPreferences) === null || _c === void 0 ? void 0 : _c.call(host, document)) !== null && _d !== void 0 ? _d : {},
        ]) : [{}, {}];
        let details;
        try {
            details = languageService.getCompletionEntryDetails(fileName, offset, name, formatOptions, source, preferences, data.tsData);
        }
        catch (err) {
            item.detail = `[TS Error] ${err}`;
        }
        if (!details)
            return item;
        const detailTexts = [];
        if (details.codeActions) {
            if (!item.additionalTextEdits)
                item.additionalTextEdits = [];
            for (const action of details.codeActions) {
                detailTexts.push(action.description);
                for (const changes of action.changes) {
                    const entries = changes.textChanges.map(textChange => {
                        return { fileName, textSpan: textChange.span };
                    });
                    const locs = transforms_1.entriesToLocations(entries, getTextDocument);
                    locs.forEach((loc, index) => {
                        var _a;
                        (_a = item.additionalTextEdits) === null || _a === void 0 ? void 0 : _a.push(vscode.TextEdit.replace(loc.range, changes.textChanges[index].newText));
                    });
                }
            }
        }
        if (details.displayParts) {
            detailTexts.push(previewer.plainWithLinks(details.displayParts, { toResource: shared.fsPathToUri }));
        }
        if (detailTexts.length) {
            item.detail = detailTexts.join('\n');
        }
        item.documentation = {
            kind: 'markdown',
            value: previewer.markdownDocumentation(details.documentation, details.tags, { toResource: shared.fsPathToUri }),
        };
        if (details) {
            completion_1.handleKindModifiers(item, details);
        }
        return item;
    };
}
exports.register = register;
//# sourceMappingURL=completionResolve.js.map