"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.register = void 0;
const vscode = require("vscode-languageserver");
const shared = require("@volar/shared");
function register(languageService, getTextDocument, ts) {
    return (uri) => {
        const document = getTextDocument(uri);
        if (!document)
            return [];
        const fileName = shared.uriToFsPath(document.uri);
        const outliningSpans = languageService.getOutliningSpans(fileName);
        const foldingRanges = [];
        for (const outliningSpan of outliningSpans) {
            outliningSpan.kind;
            const start = document.positionAt(outliningSpan.textSpan.start);
            const end = document.positionAt(outliningSpan.textSpan.start + outliningSpan.textSpan.length);
            const foldingRange = vscode.FoldingRange.create(start.line, end.line, start.character, end.character, transformFoldingRangeKind(outliningSpan.kind));
            foldingRanges.push(foldingRange);
        }
        return foldingRanges;
    };
    function transformFoldingRangeKind(tsKind) {
        switch (tsKind) {
            case ts.OutliningSpanKind.Comment: return vscode.FoldingRangeKind.Comment;
            case ts.OutliningSpanKind.Imports: return vscode.FoldingRangeKind.Imports;
            case ts.OutliningSpanKind.Region: return vscode.FoldingRangeKind.Region;
        }
    }
}
exports.register = register;
//# sourceMappingURL=foldingRanges.js.map