"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.register = void 0;
const vscode = require("vscode-languageserver");
const previewer = require("../utils/previewer");
const shared = require("@volar/shared");
function register(languageService, getTextDocument, ts) {
    return (uri, position, documentOnly = false) => {
        var _a, _b, _c;
        const document = getTextDocument(uri);
        if (!document)
            return;
        const fileName = shared.uriToFsPath(document.uri);
        const offset = document.offsetAt(position);
        const info = languageService.getQuickInfoAtPosition(fileName, offset);
        if (!info)
            return;
        const parts = [];
        const displayString = ts.displayPartsToString(info.displayParts);
        // fix https://github.com/johnsoncodehk/volar/issues/289
        const mapedTags = (_b = (_a = info.tags) === null || _a === void 0 ? void 0 : _a.map(tag => {
            if (tag.text) {
                return {
                    ...tag,
                    text: tag.text.map(part => {
                        let target = part.target;
                        if (target && 'fileName' in target) {
                            const fileDoc = getTextDocument(shared.uriToFsPath(target.fileName));
                            const start = fileDoc.positionAt(target.textSpan.start);
                            const end = fileDoc.positionAt(target.textSpan.start + target.textSpan.length);
                            target = {
                                file: target.fileName,
                                start: {
                                    line: start.line + 1,
                                    offset: start.character + 1,
                                },
                                end: {
                                    line: end.line + 1,
                                    offset: end.character + 1,
                                },
                            };
                            return {
                                ...part,
                                target,
                            };
                        }
                        return part;
                    }),
                };
            }
            return tag;
        })) !== null && _b !== void 0 ? _b : [];
        const documentation = previewer.markdownDocumentation((_c = info.documentation) !== null && _c !== void 0 ? _c : [], mapedTags, { toResource: shared.fsPathToUri });
        if (displayString && !documentOnly) {
            parts.push(['```typescript', displayString, '```'].join('\n'));
        }
        if (documentation) {
            parts.push(documentation);
        }
        const markdown = {
            kind: vscode.MarkupKind.Markdown,
            value: parts.join('\n\n'),
        };
        return {
            contents: markdown,
            range: vscode.Range.create(document.positionAt(info.textSpan.start), document.positionAt(info.textSpan.start + info.textSpan.length)),
        };
    };
}
exports.register = register;
//# sourceMappingURL=hover.js.map